# Changelog

All notable changes to this project will be documented in this file.

This changelog is automatically managed by release-please from commits merged into `main`.

## [0.2.0](https://github.com/dimidagd/transformers-knn-adapter/compare/v0.1.0...v0.2.0) (2026-03-05)


### Features

* **cli:** add infer mode for single and batched image prediction ([47a291b](https://github.com/dimidagd/transformers-knn-adapter/commit/47a291b9156ad63d9263430366aded4687a8b16b))


### Documentation

* **readme:** add infer command usage example ([6b01105](https://github.com/dimidagd/transformers-knn-adapter/commit/6b01105379de1d4edc66294eaddd460c301352de))

## [Unreleased]
